@@ -3,7 +3,7 @@ package Char::Eusascii;
 #
 # Char::Eusascii - Run-time routines for Char/USASCII.pm
 #
-# Copyright (c) 2008, 2009, 2010, 2011, 2012 INABA Hitoshi <ina@cpan.org>
+# Copyright (c) 2008, 2009, 2010, 2011, 2012, 2013 INABA Hitoshi <ina@cpan.org>
 #
 ######################################################################
 
@@ -27,7 +27,7 @@ BEGIN {
 # (and so on)
 
 BEGIN { eval q{ use vars qw($VERSION) } }
-$VERSION = sprintf '%d.%02d', q$Revision: 0.84 $ =~ /(\d+)/xmsg;
+$VERSION = sprintf '%d.%02d', q$Revision: 0.85 $ =~ /(\d+)/xmsg;
 
 BEGIN {
     my $PERL5LIB = __FILE__;
@@ -87,14 +87,14 @@ BEGIN {
 
         my $ref = \*{$genpkg . $name};
         delete $$genpkg{$name};
-        $ref;
+        return $ref;
     }
 
     sub qualify ($;$) {
         my ($name) = @_;
         if (!ref($name) && (Char::Eusascii::index($name, '::') == -1) && (Char::Eusascii::index($name, "'") == -1)) {
             my $pkg;
-            my %global = map {$_ => 1} qw(ARGV ARGVOUT ENV INC SIG STDERR STDIN STDOUT);
+            my %global = map {$_ => 1} qw(ARGV ARGVOUT ENV INC SIG STDERR STDIN STDOUT DATA);
 
             # Global names: special character, "^xyz", or other.
             if ($name =~ /^(([^a-z])|(\^[a-z_]+))\z/i || $global{$name}) {
@@ -107,7 +107,7 @@ BEGIN {
             }
             $name = $pkg . "::" . $name;
         }
-        $name;
+        return $name;
     }
 
     sub qualify_to_ref ($;$) {
@@ -118,9 +118,14 @@ BEGIN {
     }
 }
 
+# Column: local $@
+# in Chapter 9. Osaete okitai Perl no kiso
+# of ISBN 10: 4798119172 | ISBN 13: 978-4798119175 MODAN Perl NYUMON
+# (and so on)
+
 # use strict; if strict.pm exists
 BEGIN {
-    if (eval {CORE::require strict}) {
+    if (eval { local $@; CORE::require strict }) {
         strict::->import;
     }
 }
@@ -139,10 +144,10 @@ sub LOCK_UN() {8}
 sub LOCK_NB() {4}
 
 # instead of Carp.pm
-sub carp(@);
-sub croak(@);
-sub cluck(@);
-sub confess(@);
+sub carp;
+sub croak;
+sub cluck;
+sub confess;
 
 my $your_char = q{[\x00-\xFF]};
 
@@ -190,7 +195,7 @@ else {
 #
 # @ARGV wildcard globbing
 #
-sub import() {
+sub import {
 
     if ($^O =~ /\A (?: MSWin32 | NetWare | symbian | dos ) \z/oxms) {
         my @argv = ();
@@ -225,10 +230,28 @@ sub import() {
     }
 }
 
+# P.230 Care with Prototypes
+# in Chapter 6: Subroutines
+# of ISBN 0-596-00027-8 Programming Perl Third Edition.
+#
+# If you aren't careful, you can get yourself into trouble with prototypes.
+# But if you are careful, you can do a lot of neat things with them. This is
+# all very powerful, of course, and should only be used in moderation to make
+# the world a better place.
+
+# P.332 Care with Prototypes
+# in Chapter 7: Subroutines
+# of ISBN 978-0-596-00492-7 Programming Perl 4th Edition.
+#
+# If you aren't careful, you can get yourself into trouble with prototypes.
+# But if you are careful, you can do a lot of neat things with them. This is
+# all very powerful, of course, and should only be used in moderation to make
+# the world a better place.
+
 #
 # Prototypes of subroutines
 #
-sub unimport() {}
+sub unimport {}
 sub Char::Eusascii::split(;$$$);
 sub Char::Eusascii::tr($$$$;$);
 sub Char::Eusascii::chop(@);
@@ -244,9 +267,9 @@ sub Char::Eusascii::uc(@);
 sub Char::Eusascii::uc_();
 sub Char::Eusascii::fc(@);
 sub Char::Eusascii::fc_();
-sub Char::Eusascii::ignorecase(@);
-sub Char::Eusascii::classic_character_class($);
-sub Char::Eusascii::capture($);
+sub Char::Eusascii::ignorecase;
+sub Char::Eusascii::classic_character_class;
+sub Char::Eusascii::capture;
 sub Char::Eusascii::chr(;$);
 sub Char::Eusascii::chr_();
 sub Char::Eusascii::glob($);
@@ -255,6 +278,7 @@ sub Char::Eusascii::glob_();
 sub Char::USASCII::ord(;$);
 sub Char::USASCII::ord_();
 sub Char::USASCII::reverse(@);
+sub Char::USASCII::getc(;*@);
 sub Char::USASCII::length(;$);
 sub Char::USASCII::substr($$;$$);
 sub Char::USASCII::index($$;$);
@@ -822,7 +846,7 @@ sub Char::Eusascii::fc_() {
 # US-ASCII regexp capture
 #
 {
-    sub Char::Eusascii::capture($) {
+    sub Char::Eusascii::capture {
         return $_[0];
     }
 }
@@ -830,7 +854,7 @@ sub Char::Eusascii::fc_() {
 #
 # US-ASCII regexp ignore case modifier
 #
-sub Char::Eusascii::ignorecase(@) {
+sub Char::Eusascii::ignorecase {
 
     my @string = @_;
     my $metachar = qr/[\@\\|[\]{]/oxms;
@@ -967,7 +991,7 @@ sub Char::Eusascii::ignorecase(@) {
 #
 # classic character class ( \D \S \W \d \s \w \C \X \H \V \h \v \R \N \b \B )
 #
-sub classic_character_class($) {
+sub Char::Eusascii::classic_character_class {
     my($char) = @_;
 
     return {
@@ -1313,7 +1337,7 @@ sub _octets {
         my($z1) = unpack 'C', $_[1];
 
         if ($a1 > $z1) {
-            croak 'Invalid [] range in regexp (ord(A) > ord(B)) ' . '\x' . unpack('H*',$a1) . '-\x' . unpack('H*',$z1);
+            croak 'Invalid [] range in regexp (CORE::ord(A) > CORE::ord(B)) ' . '\x' . unpack('H*',$a1) . '-\x' . unpack('H*',$z1);
         }
 
         if ($a1 == $z1) {
@@ -1582,7 +1606,7 @@ sub _charlist {
             }
             elsif (CORE::length($char[$i-1]) == CORE::length($char[$i+1])) {
                 if ($char[$i-1] gt $char[$i+1]) {
-                    croak 'Invalid [] range in regexp (ord(A) > ord(B)) ' . '\x' . unpack('H*',$char[$i-1]) . '-\x' . unpack('H*',$char[$i+1]);
+                    croak 'Invalid [] range in regexp (CORE::ord(A) > CORE::ord(B)) ' . '\x' . unpack('H*',$char[$i-1]) . '-\x' . unpack('H*',$char[$i+1]);
                 }
             }
 
@@ -2440,6 +2464,27 @@ sub Char::USASCII::reverse(@) {
     }
 }
 
+#
+# US-ASCII getc (with parameter, without parameter)
+#
+sub Char::USASCII::getc(;*@) {
+
+    my $fh = @_ ? qualify_to_ref(shift) : \*STDIN;
+    croak 'Too many arguments for Char::USASCII::getc' if @_ and not wantarray;
+
+    my @length = sort { $a <=> $b } keys %range_tr;
+    my $getc = '';
+    for my $length ($length[0] .. $length[-1]) {
+        $getc .= CORE::getc($fh);
+        if (exists $range_tr{CORE::length($getc)}) {
+            if ($getc =~ /\A ${Char::Eusascii::dot_s} \z/oxms) {
+                return wantarray ? ($getc,@_) : $getc;
+            }
+        }
+    }
+    return wantarray ? ($getc,@_) : $getc;
+}
+
 #
 # US-ASCII length by character
 #
@@ -2537,7 +2582,7 @@ sub Char::USASCII::rindex($$;$) {
 #
 # instead of Carp::carp
 #
-sub carp(@) {
+sub carp {
     my($package,$filename,$line) = caller(1);
     print STDERR "@_ at $filename line $line.\n";
 }
@@ -2545,7 +2590,7 @@ sub carp(@) {
 #
 # instead of Carp::croak
 #
-sub croak(@) {
+sub croak {
     my($package,$filename,$line) = caller(1);
     print STDERR "@_ at $filename line $line.\n";
     die "\n";
@@ -2554,14 +2599,14 @@ sub croak(@) {
 #
 # instead of Carp::cluck
 #
-sub cluck(@) {
+sub cluck {
     my $i = 0;
     my @cluck = ();
     while (my($package,$filename,$line,$subroutine) = caller($i)) {
         push @cluck, "[$i] $filename($line) $package::$subroutine\n";
         $i++;
     }
-    print STDERR reverse @cluck;
+    print STDERR CORE::reverse @cluck;
     print STDERR "\n";
     carp @_;
 }
@@ -2569,14 +2614,14 @@ sub cluck(@) {
 #
 # instead of Carp::confess
 #
-sub confess(@) {
+sub confess {
     my $i = 0;
     my @confess = ();
     while (my($package,$filename,$line,$subroutine) = caller($i)) {
         push @confess, "[$i] $filename($line) $package::$subroutine\n";
         $i++;
     }
-    print STDERR reverse @confess;
+    print STDERR CORE::reverse @confess;
     print STDERR "\n";
     croak @_;
 }
@@ -3098,5 +3143,9 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
   # absolute path
   @abspath_file = split(/\n/,`dir /s /b wildcard\\here*.txt 2>NUL`);
 
+  # on COMMAND.COM
+  @relpath_file = split(/\n/,`dir /b wildcard\\here*.txt`);
+  @abspath_file = split(/\n/,`dir /s /b wildcard\\here*.txt`);
+
 =cut
 
